==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/complex/EducationAssignmentIndividualRecipient.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.CollectionPage;
import com.github.davidmoten.odata.client.HttpRequestOptions;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.EdmSchemaInfo;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "recipients"})
@JsonInclude(Include.NON_NULL)
public class EducationAssignmentIndividualRecipient extends EducationAssignmentRecipient implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected UnmappedFields unmappedFields;

    @JsonProperty("recipients")
    protected List<String> recipients;

    @JsonProperty("recipients@nextLink")
    protected String recipientsNextLink;

    protected EducationAssignmentIndividualRecipient() {
        super();
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.educationAssignmentIndividualRecipient";
    }

    @Property(name="recipients")
    @JsonIgnore
    public CollectionPage<String> getRecipients() {
        return new CollectionPage<String>(contextPath, String.class, recipients, Optional.ofNullable(recipientsNextLink), EdmSchemaInfo.INSTANCE, Collections.emptyList(), HttpRequestOptions.EMPTY);
    }

    @Property(name="recipients")
    @JsonIgnore
    public CollectionPage<String> getRecipients(HttpRequestOptions options) {
        return new CollectionPage<String>(contextPath, String.class, recipients, Optional.ofNullable(recipientsNextLink), EdmSchemaInfo.INSTANCE, Collections.emptyList(), options);
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderEducationAssignmentIndividualRecipient() {
        return new Builder();
    }

    public static final class Builder {
        private List<String> recipients;
        private String recipientsNextLink;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder recipients(List<String> recipients) {
            this.recipients = recipients;
            this.changedFields = changedFields.add("recipients");
            return this;
        }

        public Builder recipients(String... recipients) {
            return recipients(Arrays.asList(recipients));
        }

        public Builder recipientsNextLink(String recipientsNextLink) {
            this.recipientsNextLink = recipientsNextLink;
            this.changedFields = changedFields.add("recipients");
            return this;
        }

        public EducationAssignmentIndividualRecipient build() {
            EducationAssignmentIndividualRecipient _x = new EducationAssignmentIndividualRecipient();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.educationAssignmentIndividualRecipient";
            _x.recipients = recipients;
            _x.recipientsNextLink = recipientsNextLink;
            return _x;
        }
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("EducationAssignmentIndividualRecipient[");
        b.append("recipients=");
        b.append(this.recipients);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-msgraph-beta-0.2.2-sources.jar: odata/msgraph/client/beta/complex/EducationAssignmentIndividualRecipient.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.CollectionPage;
import com.github.davidmoten.odata.client.HttpRequestOptions;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "recipients"})
@JsonInclude(Include.NON_NULL)
public class EducationAssignmentIndividualRecipient extends EducationAssignmentRecipient implements ODataType {

    @JsonProperty("recipients")
    protected List<String> recipients;

    @JsonProperty("recipients@nextLink")
    protected String recipientsNextLink;

    protected EducationAssignmentIndividualRecipient() {
        super();
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.educationAssignmentIndividualRecipient";
    }

    @Property(name="recipients")
    @JsonIgnore
    public CollectionPage<String> getRecipients() {
        return new CollectionPage<String>(contextPath, String.class, this.recipients, Optional.ofNullable(recipientsNextLink), Collections.emptyList(), HttpRequestOptions.EMPTY);
    }

    @Property(name="recipients")
    @JsonIgnore
    public CollectionPage<String> getRecipients(HttpRequestOptions options) {
        return new CollectionPage<String>(contextPath, String.class, this.recipients, Optional.ofNullable(recipientsNextLink), Collections.emptyList(), options);
    }

    public EducationAssignmentIndividualRecipient withUnmappedField(String name, Object value) {
        EducationAssignmentIndividualRecipient _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderEducationAssignmentIndividualRecipient() {
        return new Builder();
    }

    public static final class Builder {
        private List<String> recipients;
        private String recipientsNextLink;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder recipients(List<String> recipients) {
            this.recipients = recipients;
            this.changedFields = changedFields.add("recipients");
            return this;
        }

        public Builder recipients(String... recipients) {
            return recipients(Arrays.asList(recipients));
        }

        public Builder recipientsNextLink(String recipientsNextLink) {
            this.recipientsNextLink = recipientsNextLink;
            this.changedFields = changedFields.add("recipients");
            return this;
        }

        public EducationAssignmentIndividualRecipient build() {
            EducationAssignmentIndividualRecipient _x = new EducationAssignmentIndividualRecipient();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.educationAssignmentIndividualRecipient";
            _x.recipients = recipients;
            _x.recipientsNextLink = recipientsNextLink;
            return _x;
        }
    }

    private EducationAssignmentIndividualRecipient _copy() {
        EducationAssignmentIndividualRecipient _x = new EducationAssignmentIndividualRecipient();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.recipients = recipients;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("EducationAssignmentIndividualRecipient[");
        b.append("recipients=");
        b.append(this.recipients);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
